Third Space Ministries - What we do

## Third Space Ministries

### demonstrating God’s love in the 'third spaces' of society

# Third Space

test - end of page content start of column bits below

## Third Space Ministries seeks to be a positive presence in the third spaces of society through:

some content here

some content heresome content heresome content heresome content heresome content heresome content heresome content heresome content heresome content heresome content heresome content heresome content heresome content heresome content heresome content heresome content heresome content here

### Love All Serve All is…

…an initiative to bless the tennis fans who come and queue for Wimbledon Tennis Championships. We work predominantly with local Christians, going to the queues at night offering free refreshments, conversation, prayer. It's a great opportunity to welcome people to Wimbledon and to experience the unique atmosphere of the Tennis Championships. It’s about loving people, and serving them.

### Club & Pray

….is for those who have a heart to pray and engage with nightclubs. A team of local Christians meet to pray for the nightclub scene, and then go to a club simply to be a positive presence there, dancing, worshipping, praying, building relationships. This is a group for those who like to dance, club, pray and serve God .. have passion and life and want to express themselves and share life with God in all areas and spheres of their lives!

### Latest news

#### 9 December 2011

Over the last few weeks we have been running a course at the gym, called Wellsprings. It's a course for women looking at issues such as rest & relaxation; acceptance & security; worry & anxiety; beauty & self image etc. And every session has a pamper treatment! It's lovely to see women take some time out to discuss how these issues impact their lives and to be able to help them consider how God values them. Last week as we had our nails painted (!) we reminded them that they are made in God's image, and God never makes mistakes!

Read more news

### Subscribe

Sign up to our newsletter, and we’ll keep you up to date with news and activities.